% loadbv() - load binary Brainvision vhdr-file and return and
%            EEGLAB structure.
%
% Usage:
%  >> EEG = loadbv(path,hdrfile);
%
% Inputs:
%   path    - Path to files
%   hdrfile - Name of Brainvision vhdr-file (including extension)
%
% Outputs:
%   EEG     EEGLAB EEG structure
%
% Author: Andreas Widmann, 2004

% Formating for EEGLAB - 11/16/2004 - Arnaud Delorme

function [EEG, com] = loadbv(path,hdrfile)

try, EEG = eeg_emptyset;
catch, end;

if nargin < 1
    [hdrfile path] = uigetfile('*', 'Select Brainvision vhdr-file - pop_loadbv()');
    if hdrfile(1) == 0, EEG = []; return; end;
end;

disp('loadbv(): read and parse header file');
if path(end) ~= filesep
    path = [path filesep];
end
[IN,message] = fopen([path hdrfile]);
if IN == -1
    error(message);
end
hdrraw={};
while ~feof(IN)
    hdrraw = [hdrraw;{fgetl(IN)}];
end
fclose(IN);

EEG.filename = char(strread(hdrraw{strmatch('DataFile',hdrraw)},'DataFile=%s'));
mrkfile = char(strread(hdrraw{strmatch('MarkerFile',hdrraw)},'MarkerFile=%s'));
EEG.nbchan = strread(hdrraw{strmatch('NumberOfChannels',hdrraw)},'NumberOfChannels=%d');
EEG.srate = 1000000 / strread(hdrraw{strmatch('SamplingInterval',hdrraw)},'SamplingInterval=%f');
for chan = 1:EEG.nbchan,
    [labels,chanlocs(chan).ref,chanlocs(chan).scale] = strread(hdrraw{strmatch(['Ch' num2str(chan) '='],hdrraw)},['Ch' num2str(chan) '=%s%s%f'],'delimiter',',');
    EEG.chanlocs(chan).labels = char(labels);
end

disp('loadbv(): read and scale EEG data');
[IN,message]=fopen([path EEG.filename]);
if IN == -1
    error(message);
end
EEG.data = fread(IN,'int16');
fclose(IN);
EEG.data =reshape(EEG.data,EEG.nbchan,[]);
EEG.pnts = size(EEG.data,2);
for chan = 1:EEG.nbchan,
    EEG.data(chan,:) = EEG.data(chan,:) .* chanlocs(chan).scale;
end

disp('loadbv(): read and parse marker file');
[IN,message] = fopen([path mrkfile]);
if IN == -1
    error(message);
end
mrkraw={};
while ~feof(IN)
    mrkraw = [mrkraw;{fgetl(IN)}];
end
fclose(IN);

markers = strmatch('Mk' ,mrkraw)';
for c = 1:size(markers,2),
    [mrkn,mrktype,mrkdesc,EEG.event(c).latency,mrksizepnts,mrkchan,mrktime] = strread(mrkraw{markers(c)}, 'Mk%d=%s%s%d%d%d%d','delimiter',',');
    if strcmp(mrktype,'New Segment') | strcmp(mrktype,'DC Correction'),
        EEG.event(c).type = 'boundary';
    else
        EEG.event(c).type = char(mrkdesc);
    end
    EEG.urevent(c).type = EEG.event(c).type;
    EEG.urevent(c).latency = EEG.event(c).latency;
end

EEG.trials = 1;
EEG.xmin = 0;
EEG.xmax = (EEG.pnts - 1) / EEG.srate;
EEG.ref = 'common';

try, EEG = EEG.checkset(EEG);
catch, end

if nargout == 2
    com = sprintf('EEG = pop_loadbv(''%s'', ''%s'');', path, hdrfile);
end;