% loadeep_avg() - Load an averaged ANT EEP file (*.avr).
%
% Usage:
%   >> [eep] = loadeep_avg(file);
%
% Inputs:
%            filename    - name of averaged ANT EEP file, including extension (*.avr)
%
% Outputs:
%   [eep]                - data structure holding continous EEG information and other
%                          relevant information.
%
% Author: Maarten-Jan Hoeve, ANT Software, The Netherlands / www.ant-software.nl, 8 October 2003
%
% See also: eeglab(), pop_loadeep_avg()

%123456789012345678901234567890123456789012345678901234567890123456789012

% Copyright (C) 2003 Maarten-Jan Hoeve, ANT Software, The Netherlands, m.hoeve@ieee.org / info@ant-software.nl
%

function r=loadeep_avg(file)

if nargin < 1
	help loadeep;
	return;
end;	

% defaults
if ~any(file=='.'), file=[file '.avr']; end
[datdir,name,ext]=fileparts(file);
disp(['Loading file ' file ' ...'])

eeg=read_eep_avr(file);

r.filename=file;
r.totsamples=eeg.npnt;
r.nchannels=eeg.nchan;
r.rate=eeg.rate;

% Create struct for holding channel labels
for i=1:r.nchannels
    chanlocs(i).labels=char(eeg.label(i));
    chanlocs(i).theta=0;
    chanlocs(i).radius=0;
    chanlocs(i).X=0;
    chanlocs(i).Y=0;
    chanlocs(i).Z=0;
    chanlocs(i).sph_theta=0;
    chanlocs(i).sph_phi=0;
    chanlocs(i).sph_radius=0;    
end
r.chanlocs=chanlocs;

r.nsmpl=eeg.npnt;
r.time=eeg.time;
r.dat=eeg.data;
r.nsweeps=eeg.nsweeps;     %number of trials averaged
r.xmin=eeg.xmin; 
r.xmax=eeg.xmax;
r.variance=eeg.variance;   % variance (nchan x npnt)
r.condlab=eeg.condlab;     % string with condition label
r.condcol=eeg.condcol;     % string with color code for condition
r.trialc=eeg.trialc;       % total number of trial in original data
r.rejtrialc=eeg.rejtrialc; % number of rejected trials